- bump version in `pyproject.toml`
- revise `README.md`
- revise `TODO.md`
- `uv run pytest`
- `uv run pytest -s src/myrtle/tests/integration_test_suite.py`
- `uv run src/myrtle/demo.py`
- `uvx ruff check`
- `uvx ruff format`
- `git add ...`
- `git commit -m "..."`
- `git push origin HEAD`
- `git push github HEAD`
- `git push gitlab HEAD`
- delete contents of `dist/`
- `uv build`
- `uv publish --token $PYPI_TOKEN`
- (as needed) update public posts
- (optional) write a blog post
- (optional) publish on social media
